@@ -234,7 +234,8 @@ setMethod("plot", "TracksCollection",
 # Provide stcube methods.
 
 map3d = function(map, z, ...) {
-	require(rgl)
+	if (!requireNamespace("rgl", quietly = TRUE))
+		stop("rgl required")
 	if(length(map$tiles) != 1)
 		stop("Pass single map tile only.")
 	nx = map$tiles[[1]]$xres
@@ -272,8 +273,10 @@ setMethod("stcube", signature(x = "Track"),
 		ylim, zlim, showMap = FALSE, mapType = "osm", ..., y, z) {
 		# "y" and "z" are ignored, but included in the method signature to avoid
 		# passing them twice to plot3d().
-		require(rgl)
-		require(OpenStreetMap)
+		if (!requireNamespace("rgl", quietly = TRUE))
+			stop("rgl required")
+		if (!requireNamespace("OpenStreetMap", quietly = TRUE))
+			stop("OpenStreetMap required")
 		coords = coordinates(x@sp)
 		time = index(x@time)
 		if(missing(aspect))
@@ -288,12 +291,13 @@ setMethod("stcube", signature(x = "Track"),
 		# rendering everything in one go.
 		if(showMap) {
 			# Required by openmap().
-			require(raster)
-			map = openmap(upperLeft = c(ylim[2], xlim[1]),
+			if (!requireNamespace("raster", quietly = TRUE))
+				stop("raster required")
+			map = OpenStreetMap::openmap(upperLeft = c(ylim[2], xlim[1]),
 				lowerRight = c(ylim[1], xlim[2]), type = mapType)
-			map = openproj(x = map, projection = proj4string(x))
+			map = OpenStreetMap::openproj(x = map, projection = proj4string(x))
 		}
-		plot3d(x = coords[, 1], y = coords[, 2], z = time, xlab = xlab,
+		rgl::glot3d(x = coords[, 1], y = coords[, 2], z = time, xlab = xlab,
 			ylab = ylab, zlab = zlab, type = type, aspect = aspect, xlim = xlim,
 			ylim = ylim, zlim = zlim, ...)
 		if(showMap)
@@ -306,8 +310,10 @@ setMethod("stcube", signature(x = "Tracks"),
 		ylim, zlim, showMap = FALSE, mapType = "osm", normalizeBy = "week", ..., y, z, col) {
 		# "y", "z" and "col" are ignored, but included in the method signature
 		# to avoid passing them twice to plot3d().
-		require(rgl)
-		require(OpenStreetMap)
+		if (!requireNamespace("rgl", quietly = TRUE))
+			stop("rgl required")
+		if (!requireNamespace("OpenStreetMap", quietly = TRUE))
+			stop("OpenStreetMap required")
 		dim = dim(x@tracks[[1]])["geometries"]
 		coordsAll = do.call(rbind, lapply(x@tracks, function(x) coordinates(x@sp)))
 		timeAll = normalize(do.call(c, lapply(x@tracks,
@@ -326,12 +332,13 @@ setMethod("stcube", signature(x = "Tracks"),
 		# rendering everything in one go.
 		if(showMap) {
 			# Required by openmap().
-			require(raster)
-			map = openmap(upperLeft = c(ylim[2], xlim[1]),
+			if (!requireNamespace("raster", quietly = TRUE))
+				stop("raster required")
+			map = OpenStreetMap::openmap(upperLeft = c(ylim[2], xlim[1]),
 				lowerRight = c(ylim[1], xlim[2]), type = mapType)
-			map = openproj(x = map, projection = proj4string(x))
+			map = OpenStreetMap::openproj(x = map, projection = proj4string(x))
 		}
-		plot3d(x = coordsAll[1:dim, 1], y = coordsAll[1:dim, 2],
+		rgl::plot3d(x = coordsAll[1:dim, 1], y = coordsAll[1:dim, 2],
 			z = timeAll[1:dim], xlab = xlab, ylab = ylab, zlab = zlab,
 			type = type, col = col[1], aspect = aspect, xlim = xlim,
 			ylim = ylim, zlim = zlim, ...)
@@ -339,7 +346,7 @@ setMethod("stcube", signature(x = "Tracks"),
 		for(t in seq_along(tracks)) {
 			coords = coordinates(tracks[[t]]@sp)
 			time = normalize(index(tracks[[t]]@time), normalizeBy, timeAll[1])
-			lines3d(x = coords[, 1], y = coords[, 2], z = time, col = col[t+1])
+			rgl::lines3d(x = coords[, 1], y = coords[, 2], z = time, col = col[t+1])
 		}
 		if(showMap)
 			map3d(map = map, z = timeAll[1])
@@ -351,8 +358,10 @@ setMethod("stcube", signature(x = "TracksCollection"),
 		ylim, zlim, showMap = FALSE, mapType = "osm", normalizeBy = "week", ..., y, z, col) {
 		# "y", "z" and "col" are ignored, but included in the method signature
 		# to avoid passing them twice to plot3d().
-		require(rgl)
-		require(OpenStreetMap)
+		if (!requireNamespace("rgl", quietly = TRUE))
+			stop("rgl required")
+		if (!requireNamespace("OpenStreetMap", quietly = TRUE))
+			stop("OpenStreetMap required")
 		dim = dim(x@tracksCollection[[1]]@tracks[[1]])["geometries"]
 		coordsAll = do.call(rbind, lapply(x@tracksCollection,
 			function(x) do.call(rbind, lapply(x@tracks, function(y) coordinates(y@sp)))))
@@ -373,12 +382,13 @@ setMethod("stcube", signature(x = "TracksCollection"),
 		# rendering everything in one go.
 		if(showMap) {
 			# Required by openmap().
-			require(raster)
-			map = openmap(upperLeft = c(ylim[2], xlim[1]),
+			if (!requireNamespace("raster", quietly = TRUE))
+				stop("raster required")
+			map = OpenStreetMap::openmap(upperLeft = c(ylim[2], xlim[1]),
 				lowerRight = c(ylim[1], xlim[2]), type = mapType)
-			map = openproj(x = map, projection = proj4string(x))
+			map = OpenStreetMap::openproj(x = map, projection = proj4string(x))
 		}
-		plot3d(x = coordsAll[1:dim, 1], y = coordsAll[1:dim, 2],
+		rgl::plot3d(x = coordsAll[1:dim, 1], y = coordsAll[1:dim, 2],
 			z = timeAll[1:dim], xlab = xlab, ylab = ylab, zlab = zlab,
 			type = type, col = col[1], aspect = aspect, xlim = xlim,
 			ylim = ylim, zlim = zlim, ...)
@@ -390,7 +400,7 @@ setMethod("stcube", signature(x = "TracksCollection"),
 			for(t in seq_along(tracks)) {
 				coords = coordinates(tracks[[t]]@sp)
 				time = normalize(index(tracks[[t]]@time), normalizeBy, timeAll[1])
-				lines3d(x = coords[, 1], y = coords[, 2], z = time, col = col[tz])
+				rgl::lines3d(x = coords[, 1], y = coords[, 2], z = time, col = col[tz])
 			}
 		}
 		if(showMap)
